#! /usr/bin/env python3
import socket


from ops.charm import CharmBase

from ops.main import main

from ops.framework import (
    Object,
    ObjectEvents,
    StoredState,
)


class PeerRelationEvents(ObjectEvents):
    """Peer Relation Events"""


class TestingPeerRelation(Object):

    on = PeerRelationEvents()

    def __init__(self, charm, relation_name):
        super().__init__(charm, relation_name)

        self.hostname = socket.gethostname()

        self.framework.observe(
            charm.on[relation_name].relation_created,
            self._on_relation_created
        )

    def _on_relation_created(self, event):
        event.relation.data[self.model.unit]['hostname'] = self.hostname


class PeererCharm(CharmBase):

    def __init__(self, *args):
        super().__init__(*args)
        
        self.slurmd_peer = TestingPeerRelation(self, "slurmd")
        
        self.framework.observe(self.on.install, self.on_install)
        self.framework.observe(self.on.start, self.on_start)

    def on_install(self, event):
        pass

    def on_start(self, event):
        pass


if __name__ == "__main__":
    main(PeererCharm)
